api.eventfilters.v1.test_helpers.filter package — Argus-Toolbelt 1.0 documentation

# api.eventfilters.v1.test_helpers.filter package

## Submodules

## api.eventfilters.v1.test_helpers.filter.error_stats module

`api.eventfilters.v1.test_helpers.filter.error_stats.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/eventfilters/v1/filter/errorstats, respond with HTTP 403

`api.eventfilters.v1.test_helpers.filter.error_stats.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/eventfilters/v1/filter/errorstats, respond with HTTP 404

`api.eventfilters.v1.test_helpers.filter.error_stats.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/eventfilters/v1/filter/errorstats, respond with HTTP 200

`api.eventfilters.v1.test_helpers.filter.error_stats.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/eventfilters/v1/filter/errorstats, respond with HTTP 401

## api.eventfilters.v1.test_helpers.filter.get module

`api.eventfilters.v1.test_helpers.filter.get.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/eventfilters/v1/filter/w+, respond with HTTP 403

`api.eventfilters.v1.test_helpers.filter.get.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/eventfilters/v1/filter/w+, respond with HTTP 404

`api.eventfilters.v1.test_helpers.filter.get.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/eventfilters/v1/filter/w+, respond with HTTP 200

`api.eventfilters.v1.test_helpers.filter.get.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/eventfilters/v1/filter/w+, respond with HTTP 401

## api.eventfilters.v1.test_helpers.filter.hit_stats module

`api.eventfilters.v1.test_helpers.filter.hit_stats.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/eventfilters/v1/filter/hitstats, respond with HTTP 403

`api.eventfilters.v1.test_helpers.filter.hit_stats.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/eventfilters/v1/filter/hitstats, respond with HTTP 404

`api.eventfilters.v1.test_helpers.filter.hit_stats.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/eventfilters/v1/filter/hitstats, respond with HTTP 200

`api.eventfilters.v1.test_helpers.filter.hit_stats.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/eventfilters/v1/filter/hitstats, respond with HTTP 401

## api.eventfilters.v1.test_helpers.filter.list module

`api.eventfilters.v1.test_helpers.filter.list.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/eventfilters/v1/filter, respond with HTTP 403

`api.eventfilters.v1.test_helpers.filter.list.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/eventfilters/v1/filter, respond with HTTP 404

`api.eventfilters.v1.test_helpers.filter.list.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/eventfilters/v1/filter, respond with HTTP 200

`api.eventfilters.v1.test_helpers.filter.list.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/eventfilters/v1/filter, respond with HTTP 401

## api.eventfilters.v1.test_helpers.filter.revisions module

`api.eventfilters.v1.test_helpers.filter.revisions.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/eventfilters/v1/filter/w+/revisions, respond with HTTP 403

`api.eventfilters.v1.test_helpers.filter.revisions.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/eventfilters/v1/filter/w+/revisions, respond with HTTP 404

`api.eventfilters.v1.test_helpers.filter.revisions.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/eventfilters/v1/filter/w+/revisions, respond with HTTP 200

`api.eventfilters.v1.test_helpers.filter.revisions.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/eventfilters/v1/filter/w+/revisions, respond with HTTP 401

## api.eventfilters.v1.test_helpers.filter.search module

`api.eventfilters.v1.test_helpers.filter.search.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/eventfilters/v1/filter/search, respond with HTTP 403

`api.eventfilters.v1.test_helpers.filter.search.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/eventfilters/v1/filter/search, respond with HTTP 404

`api.eventfilters.v1.test_helpers.filter.search.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/eventfilters/v1/filter/search, respond with HTTP 200

`api.eventfilters.v1.test_helpers.filter.search.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/eventfilters/v1/filter/search, respond with HTTP 401

## api.eventfilters.v1.test_helpers.filter.set_log_level module

`api.eventfilters.v1.test_helpers.filter.set_log_level.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/eventfilters/v1/filter/w+/logging, respond with HTTP 403

`api.eventfilters.v1.test_helpers.filter.set_log_level.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/eventfilters/v1/filter/w+/logging, respond with HTTP 404

`api.eventfilters.v1.test_helpers.filter.set_log_level.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/eventfilters/v1/filter/w+/logging, respond with HTTP 200

`api.eventfilters.v1.test_helpers.filter.set_log_level.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/eventfilters/v1/filter/w+/logging, respond with HTTP 401

## Module contents